# 🌐 Jasper

The 2024 Jasper wildfire.

![image](https://kamangir-public.s3.ca-central-1.amazonaws.com/geo-watch-2024-09-06-Jasper-a/geo-watch-2024-09-06-Jasper-a-2X.gif?raw=true&random=mJahtfyzlU0VkVYT)

--table--

The fire originates in the bottom right, crosses the river, and causes the colors to shift from green to brown.

--urls--

--footer--